@@ -55,7 +55,7 @@ class OAuthToken(Token):
             error[Constants.CLASS] = OAuthToken.__name__
             raise SDKException(code=Constants.TOKEN_ERROR, details=error)
 
-        if client_secret is not None and not isinstance(client_secret, str):
+        if not isinstance(client_secret, str):
             error[Constants.FIELD] = Constants.CLIENT_SECRET
             error[Constants.EXPECTED_TYPE] = Constants.STRING
             error[Constants.CLASS] = OAuthToken.__name__
@@ -229,6 +229,7 @@ class OAuthToken(Token):
 
         self.__user_mail = user_mail
 
+
     def authenticate(self, url_connection):
         with OAuthToken.lock:
             initializer = Initializer.get_initializer()
