@@ -22,7 +22,9 @@ class DBStore(TokenStore):
     This class to store user token details to the MySQL DataBase.
     """
 
-    def __init__(self, host=None, database_name=None, user_name=None, password=None, port_number=None, table_name=None):
+    def __init__(self, host=Constants.MYSQL_HOST, database_name=Constants.MYSQL_DATABASE_NAME,
+                 user_name=Constants.MYSQL_USER_NAME, password="", port_number=Constants.MYSQL_PORT_NUMBER,
+                 table_name=Constants.MYSQL_TABLE_NAME):
 
         """
         Creates a DBStore class instance with the specified parameters.
@@ -35,12 +37,12 @@ class DBStore(TokenStore):
             port_number (str) : A string containing the DataBase port number. Default value is 3306
         """
 
-        self.__host = host if host is not None else Constants.MYSQL_HOST
-        self.__database_name = database_name if database_name is not None else Constants.MYSQL_DATABASE_NAME
-        self.__user_name = user_name if user_name is not None else Constants.MYSQL_USER_NAME
-        self.__password = password if password is not None else ""
-        self.__port_number = port_number if port_number is not None else Constants.MYSQL_PORT_NUMBER
-        self.__table_name = table_name if table_name is not None else Constants.MYSQL_TABLE_NAME
+        self.__host = host
+        self.__database_name = database_name
+        self.__user_name = user_name
+        self.__password = password
+        self.__port_number = port_number
+        self.__table_name = table_name
 
     def get_host(self):
         """
@@ -113,12 +115,13 @@ class DBStore(TokenStore):
                     result = cursor.fetchone()
 
                     if result is not None:
-                        token.set_id(result[1])
-                        token.set_access_token(result[6])
-                        token.set_expires_in(str(result[8]))
-                        token.set_refresh_token(result[5])
-
-                        return token
+                        oauthtoken = OAuthToken(client_id=result[2], client_secret=result[3], grant_token=result[6],
+                                                 refresh_token=result[4], redirect_url=result[8])
+                        oauthtoken.set_id(result[0])
+                        oauthtoken.set_access_token(result[5])
+                        oauthtoken.set_expires_in(str(result[7]))
+                        oauthtoken.set_user_mail(result[1])
+                        return oauthtoken
 
             except Error as ex:
                 raise ex
@@ -140,7 +143,7 @@ class DBStore(TokenStore):
                     token.set_user_mail(user.get_email())
                     self.delete_token(token)
                     cursor = connection.cursor()
-                    query = "insert into oauthtoken (id,user_mail,client_id,client_secret,refresh_token,access_token,grant_token,expiry_time,redirect_url) values (%s,%s,%s,%s,%s,%s,%s,%s,%s);"
+                    query = "insert into "+self.__table_name+" (id,user_mail,client_id,client_secret,refresh_token,access_token,grant_token,expiry_time,redirect_url) values (%s,%s,%s,%s,%s,%s,%s,%s,%s);"
                     val = (token.get_id(), user.get_email(), token.get_client_id(), token.get_client_secret(), token.get_refresh_token(), token.get_access_token(), token.get_grant_token(), token.get_expires_in(), token.get_redirect_url())
                     cursor.execute(query, val)
                     connection.commit()
@@ -190,16 +193,12 @@ class DBStore(TokenStore):
                 results = cursor.fetchall()
 
                 for result in results:
-                    grant_token = None
 
-                    if result[7] is not None and result[7] != Constants.NULL_VALUE and len(result[7]) > 0:
-                        grant_token = result[7]
-
-                    token = OAuthToken(client_id=result[3], client_secret=None, grant_token=grant_token, refresh_token=result[5])
-                    token.set_id(result[1])
-                    token.set_expires_in(str(result[8]))
-                    token.set_user_mail(result[2])
-                    token.set_access_token(result[6])
+                    token = OAuthToken(client_id=result[2], client_secret=result[3], grant_token=result[6], refresh_token=result[4], redirect_url=result[8])
+                    token.set_id(result[0])
+                    token.set_expires_in(str(result[7]))
+                    token.set_user_mail(result[1])
+                    token.set_access_token(result[5])
                     tokens.append(token)
 
                 return tokens
@@ -247,13 +246,14 @@ class DBStore(TokenStore):
                     results = cursor.fetchall()
 
                     for result in results:
-                        if result[1] == id:
-                            token = OAuthToken(client_id=result[3], client_secret=result[4], redirect_url=result[9], grant_token=result[7], refresh_token=result[5])
-                            token.set_id(result[1])
-                            token.set_access_token(result[6])
-                            token.set_expires_in(str(result[8]))
-                            token.set_user_mail(result[2])
-                            return token
+                        if result[0] == id:
+
+                            oauthtoken = OAuthToken(client_id=result[2], client_secret=result[3], grant_token=result[6], refresh_token=result[4], redirect_url=result[8])
+                            oauthtoken.set_id(result[0])
+                            oauthtoken.set_access_token(result[5])
+                            oauthtoken.set_expires_in(str(result[7]))
+                            oauthtoken.set_user_mail(result[1])
+                            return oauthtoken
 
             except Error as ex:
                 raise ex
