@@ -341,7 +341,7 @@ class Attachment(object):
 		The method to get the id
 
 		Returns:
-			int: An int representing the id
+			string: A string representing the id
 		"""
 
 		return self.__id
@@ -351,11 +351,11 @@ class Attachment(object):
 		The method to set the value to id
 
 		Parameters:
-			id (int) : An int representing the id
+			id (string) : A string representing the id
 		"""
 
-		if id is not None and not isinstance(id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		if id is not None and not isinstance(id, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: str', None, None)
 		
 		self.__id = id
 		self.__key_modified['id'] = 1
