@@ -21,7 +21,7 @@ class BluePrint(object):
 		The method to get the transition_id
 
 		Returns:
-			int: A int value
+			int: An int representing the transition_id
 		"""
 
 		return self.__transition_id
@@ -130,7 +130,7 @@ class BluePrint(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
