@@ -39,7 +39,7 @@ class BluePrintOperations(object):
 
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
@@ -77,7 +77,7 @@ class BluePrintOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
