@@ -4,9 +4,9 @@ try:
     import os
     import json
     import threading
+    from zcrmsdk.src.com.zoho.crm.api.user_signature import UserSignature
     from zcrmsdk.src.com.zoho.api.authenticator.store.token_store import TokenStore
     from zcrmsdk.src.com.zoho.crm.api.exception.sdk_exception import SDKException
-    from zcrmsdk.src.com.zoho.crm.api.user_signature import UserSignature
     from zcrmsdk.src.com.zoho.crm.api.dc.data_center import DataCenter
     from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
     from zcrmsdk.src.com.zoho.api.authenticator.token import Token
@@ -14,15 +14,14 @@ try:
     from zcrmsdk.src.com.zoho.crm.api.request_proxy import RequestProxy
     from zcrmsdk.src.com.zoho.crm.api.sdk_config import SDKConfig
 
-
 except Exception:
     import logging
     import os
     import json
     import threading
+    from ..api.user_signature import UserSignature
     from ...api.authenticator.store.token_store import TokenStore
     from ..api.exception import SDKException
-    from ..api.user_signature import UserSignature
     from ..api.dc.data_center import DataCenter
     from ..api.util.constants import Constants
     from ...api.authenticator.token import Token
@@ -80,13 +79,13 @@ class Initializer(object):
 
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
 
-            if not isinstance(store, TokenStore):
-                error = {Constants.FIELD: Constants.STORE, Constants.EXPECTED_TYPE: TokenStore.__module__}
+            if not isinstance(token, Token):
+                error = {Constants.FIELD: Constants.TOKEN, Constants.EXPECTED_TYPE: Token.__module__}
 
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
 
-            if not isinstance(token, Token):
-                error = {Constants.FIELD: Constants.TOKEN, Constants.EXPECTED_TYPE: Token.__module__}
+            if not isinstance(store, TokenStore):
+                error = {Constants.FIELD: Constants.STORE, Constants.EXPECTED_TYPE: TokenStore.__module__}
 
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
 
@@ -103,11 +102,21 @@ class Initializer(object):
 
                 raise SDKException(Constants.INITIALIZATION_ERROR, Constants.INITIALIZATION_EXCEPTION, details=error)
 
-            if logger is not None:
-                SDKLogger.initialize(logger)
+            if logger is None:
+                logger = Logger(Logger.Levels.INFO, os.path.join(os.getcwd(), Constants.LOGFILE_NAME))
 
-            else:
-                SDKLogger.initialize(Logger(Logger.Levels.INFO, os.path.join(os.getcwd(), Constants.LOGFILE_NAME)))
+            SDKLogger.initialize(logger)
+
+            if not os.path.isdir(resource_path):
+                raise SDKException(Constants.INITIALIZATION_ERROR, Constants.RESOURCE_PATH_INVALID_ERROR_MESSAGE)
+
+            try:
+                json_details_path = os.path.join(os.path.dirname(__file__), '..', '..', '..', '..', Constants.JSON_DETAILS_FILE_PATH)
+
+                with open(json_details_path, mode='r') as JSON:
+                    Initializer.json_details = json.load(JSON)
+            except Exception as e:
+                raise SDKException(code=Constants.JSON_DETAILS_ERROR, cause=e)
 
             initializer = Initializer()
 
@@ -126,13 +135,8 @@ class Initializer(object):
         except SDKException as e:
             raise e
 
-        json_details_path = os.path.join(os.path.dirname(__file__), '..', '..', '..', '..', Constants.JSON_DETAILS_FILE_PATH)
-
-        with open(json_details_path, mode='r') as JSON:
-            Initializer.json_details = json.load(JSON)
-
     def __str__(self):
-        return Constants.FOR_EMAIL_ID + Initializer.get_initializer().user.email + Constants.IN_ENVIRONMENT + Initializer.get_initializer().environment.url + '.'
+        return Constants.FOR_EMAIL_ID + Initializer.get_initializer().user.get_email() + Constants.IN_ENVIRONMENT + Initializer.get_initializer().environment.url + '.'
 
     @staticmethod
     def get_initializer():
@@ -171,6 +175,9 @@ class Initializer(object):
             proxy (RequestProxy) : A RequestProxy class instance containing the proxy properties of the user.
         """
 
+        if Initializer.initializer is None:
+            raise SDKException(Constants.SDK_UNINITIALIZATION_ERROR, Constants.SDK_UNINITIALIZATION_MESSAGE)
+
         if not isinstance(user, UserSignature):
             error = {Constants.FIELD: Constants.USER, Constants.EXPECTED_TYPE: UserSignature.__module__}
 
