@@ -22,6 +22,8 @@ class Layout(object):
 		self.__created_by = None
 		self.__sections = None
 		self.__status = None
+		self.__display_type = None
+		self.__show_business_card = None
 		self.__key_modified = dict()
 
 	def get_created_time(self):
@@ -331,6 +333,54 @@ class Layout(object):
 		self.__status = status
 		self.__key_modified['status'] = 1
 
+	def get_display_type(self):
+		"""
+		The method to get the display_type
+
+		Returns:
+			int: An int representing the display_type
+		"""
+
+		return self.__display_type
+
+	def set_display_type(self, display_type):
+		"""
+		The method to set the value to display_type
+
+		Parameters:
+			display_type (int) : An int representing the display_type
+		"""
+
+		if display_type is not None and not isinstance(display_type, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: display_type EXPECTED TYPE: int', None, None)
+		
+		self.__display_type = display_type
+		self.__key_modified['display_type'] = 1
+
+	def get_show_business_card(self):
+		"""
+		The method to get the show_business_card
+
+		Returns:
+			bool: A bool representing the show_business_card
+		"""
+
+		return self.__show_business_card
+
+	def set_show_business_card(self, show_business_card):
+		"""
+		The method to set the value to show_business_card
+
+		Parameters:
+			show_business_card (bool) : A bool representing the show_business_card
+		"""
+
+		if show_business_card is not None and not isinstance(show_business_card, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: show_business_card EXPECTED TYPE: bool', None, None)
+		
+		self.__show_business_card = show_business_card
+		self.__key_modified['show_business_card'] = 1
+
 	def is_key_modified(self, key):
 		"""
 		The method to check if the user has modified the given key
