@@ -95,15 +95,4 @@ class Downloader(Converter):
         class_holder = getattr(imported_module, class_name)
         return class_holder
 
-    @staticmethod
-    def module_to_class(module_name):
-        class_name = module_name
 
-        if "_" in module_name:
-            class_name = ''
-            module_split = str(module_name).split('_')
-            for each_name in module_split:
-                each_name = each_name.capitalize()
-                class_name += each_name
-
-        return class_name
