@@ -57,15 +57,13 @@ class Utility(object):
                 split_lower = api_path_split[i].lower()
                 if split_lower == module_api_name.lower():
                     api_path_split[i] = module_api_name
-                elif Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) is not None:
+                elif split_lower in Constants.DEFAULT_MODULENAME_VS_APINAME.get(
+                        split_lower) and Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) is not None:
                     api_path_split[i] = Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower)
 
             api_path = "/".join(api_path_split)
             handler_instance.set_api_path(api_path)
 
-
-
-
     @staticmethod
     def get_fields(module_api_name, handler_instance=None):
 
@@ -106,7 +104,8 @@ class Utility(object):
                     Utility.new_file = True
                     Utility.fill_data_type()
                     api_supported_modules = Utility.get_modules(None)
-                    record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(record_field_details_path) else {}
+                    record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(
+                        record_field_details_path) else {}
 
                     record_field_details_json[Constants.FIELDS_LAST_MODIFIED_TIME] = time.time() * 1000
 
@@ -115,7 +114,8 @@ class Utility(object):
                             record_field_details_json[module.lower()] = {}
                             Utility.write_to_file(file_path=record_field_details_path,
                                                   file_contents=record_field_details_json)
-                            field_details = Utility.get_fields_details(api_supported_modules[module][Constants.API_NAME])
+                            field_details = Utility.get_fields_details(
+                                api_supported_modules[module][Constants.API_NAME])
                             record_field_details_json = Initializer.get_json(record_field_details_path)
                             record_field_details_json[module.lower()] = field_details
                             Utility.write_to_file(file_path=record_field_details_path,
@@ -222,16 +222,16 @@ class Utility(object):
 
     @staticmethod
     def verify_module_api_name(module_api_name):
-        if module_api_name is not None and Constants.DEFAULT_MODULENAME_VS_APINAME.get(module_api_name.lower()) is not None:
+        if module_api_name is not None and Constants.DEFAULT_MODULENAME_VS_APINAME.get(
+                module_api_name.lower()) is not None:
             return Constants.DEFAULT_MODULENAME_VS_APINAME.get(module_api_name.lower())
 
         record_field_details_path = Utility.get_file_name()
-        if not os.path.exists:
-            os.makedirs(record_field_details_path)
-
-        fields_json = Initializer.get_json(record_field_details_path)
-        if Constants.SDK_MODULE_METADATA in fields_json and module_api_name.lower() in fields_json[Constants.SDK_MODULE_METADATA]:
-            return fields_json[Constants.SDK_MODULE_METADATA][module_api_name.lower()][Constants.API_NAME]
+        if os.path.exists(record_field_details_path):
+            fields_json = Initializer.get_json(record_field_details_path)
+            if Constants.SDK_MODULE_METADATA in fields_json and module_api_name.lower() in fields_json[
+                Constants.SDK_MODULE_METADATA]:
+                return fields_json[Constants.SDK_MODULE_METADATA][module_api_name.lower()][Constants.API_NAME]
 
         return module_api_name
 
@@ -240,7 +240,8 @@ class Utility(object):
         subform_modules = []
         fields_json = record_field_details_json[module.lower()]
         for key, value in fields_json.items():
-            if Constants.SUBFORM in value and value[Constants.SUBFORM] and (value[Constants.MODULE]).lower() in record_field_details_json:
+            if Constants.SUBFORM in value and value[Constants.SUBFORM] and (
+                    value[Constants.MODULE]).lower() in record_field_details_json:
                 subform_modules.append(value[Constants.MODULE])
 
         del record_field_details_json[module.lower()]
@@ -270,7 +271,8 @@ class Utility(object):
                 record_field_details_path = Utility.get_file_name()
 
                 if not os.path.exists(record_field_details_path) or (
-                        os.path.exists(record_field_details_path) and key not in Initializer.get_json(record_field_details_path)):
+                        os.path.exists(record_field_details_path) and key not in Initializer.get_json(
+                    record_field_details_path)):
                     is_new_data = True
                     related_list_values = Utility.get_related_list_details(module_api_name)
                     record_field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(
@@ -300,12 +302,14 @@ class Utility(object):
     @staticmethod
     def check_related_list_exists(related_module_name, module_related_list_array, common_api_handler):
         for related_list_jo in module_related_list_array:
-            if related_list_jo[Constants.API_NAME] is not None and related_list_jo[Constants.API_NAME].lower() == related_module_name.lower():
+            if related_list_jo[Constants.API_NAME] is not None and related_list_jo[
+                Constants.API_NAME].lower() == related_module_name.lower():
                 if related_list_jo[Constants.HREF] == Constants.NULL_VALUE:
-                    raise SDKException(code=Constants.UNSUPPORTED_IN_API, message=common_api_handler.get_http_method() + ' ' + common_api_handler.get_api_path() + Constants.UNSUPPORTED_IN_API_MESSAGE)
+                    raise SDKException(code=Constants.UNSUPPORTED_IN_API,
+                                       message=common_api_handler.get_http_method() + ' ' + common_api_handler.get_api_path() + Constants.UNSUPPORTED_IN_API_MESSAGE)
 
                 if related_list_jo[Constants.MODULE] != Constants.NULL_VALUE:
-                    common_api_handler.set_module_api_name(related_list_jo[Constants.MODULE], common_api_handler)
+                    common_api_handler.set_module_api_name(related_list_jo[Constants.MODULE])
                     Utility.get_fields(related_list_jo[Constants.MODULE])
                 return True
 
@@ -324,7 +328,8 @@ class Utility(object):
                     module_meta_data = modules[module_api_name.lower()]
 
                     if module_meta_data[Constants.GENERATED_TYPE] != Constants.GENERATED_TYPE_CUSTOM:
-                        raise SDKException(code = Constants.UPLOAD_PHOTO_UNSUPPORTED_ERROR, message= Constants.UPLOAD_PHOTO_UNSUPPORTED_MESSAGE + module_api_name)
+                        raise SDKException(code=Constants.UPLOAD_PHOTO_UNSUPPORTED_ERROR,
+                                           message=Constants.UPLOAD_PHOTO_UNSUPPORTED_MESSAGE + module_api_name)
             except SDKException as e:
                 raise e
 
@@ -363,9 +368,10 @@ class Utility(object):
 
     @staticmethod
     def write_module_meta_data(record_field_details_path, module_data):
-        field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(record_field_details_path) else {}
+        field_details_json = Initializer.get_json(record_field_details_path) if os.path.exists(
+            record_field_details_path) else {}
         field_details_json[Constants.SDK_MODULE_METADATA] = module_data
-        Utility.write_to_file(record_field_details_path,field_details_json)
+        Utility.write_to_file(record_field_details_path, field_details_json)
 
     @staticmethod
     def get_related_list_details(module_api_name):
@@ -533,7 +539,7 @@ class Utility(object):
                 }
                 raise SDKException(code=Constants.API_EXCEPTION, details=error_response)
 
-        if header is None:
+        if Utility.force_refresh:
             try:
                 Utility.write_module_meta_data(Utility.get_file_name(), api_names)
             except Exception as e:
@@ -576,10 +582,12 @@ class Utility(object):
         module = ''
         key_name = field.get_api_name()
 
-        if field.get_system_mandatory() is not None and field.get_system_mandatory() and not(module_api_name.lower() == Constants.CALLS and key_name.lower() == Constants.CALL_DURATION):
+        if field.get_system_mandatory() is not None and field.get_system_mandatory() and not (
+                module_api_name.lower() == Constants.CALLS and key_name.lower() == Constants.CALL_DURATION):
             field_detail[Constants.REQUIRED] = True
 
-        if  key_name.lower() in Constants.KEY_VS_INVENTORY_MODULE and module_api_name.lower() == Constants.KEY_VS_INVENTORY_MODULE.get(key_name.lower()):
+        if key_name in Constants.KEY_VS_INVENTORY_MODULE and module_api_name.lower() == Constants.KEY_VS_INVENTORY_MODULE.get(
+                key_name):
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
             field_detail[Constants.STRUCTURE_NAME] = Constants.INVENTORY_LINE_ITEMS
@@ -604,7 +612,8 @@ class Utility(object):
 
             return
 
-        elif key_name.lower() == Constants.COMMENTS.lower() and (module_api_name.lower() == Constants.SOLUTIONS or module_api_name.lower() == Constants.CASES):
+        elif key_name.lower() == Constants.COMMENTS.lower() and (
+                module_api_name.lower() == Constants.SOLUTIONS or module_api_name.lower() == Constants.CASES):
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
             field_detail[Constants.STRUCTURE_NAME] = Constants.COMMENT_NAMESPACE
@@ -641,13 +650,13 @@ class Utility(object):
         else:
             return
 
-        if api_type.lower() in Constants.LOOKUP:
+        if Constants.LOOKUP in api_type.lower():
             field_detail[Constants.LOOKUP] = True
 
-        if api_type.lower() in Constants.CONSENT_LOOKUP:
+        if Constants.CONSENT_LOOKUP in api_type.lower():
             field_detail[Constants.SKIP_MANDATORY] = True
 
-        if api_type.lower() in Constants.MULTI_SELECT_LOOKUP:
+        if Constants.MULTI_SELECT_LOOKUP in api_type.lower():
             field_detail[Constants.SKIP_MANDATORY] = True
             if field.get_multiselectlookup() is not None:
                 if field.get_multiselectlookup().get_linking_module() is not None:
@@ -657,7 +666,7 @@ class Utility(object):
 
             field_detail[Constants.SUBFORM] = True
 
-        if api_type.lower() in Constants.MULTI_USER_LOOKUP:
+        if Constants.MULTI_USER_LOOKUP in api_type.lower():
             field_detail[Constants.SKIP_MANDATORY] = True
             if field.get_multiuserlookup() is not None:
                 if field.get_multiuserlookup().get_linking_module() is not None:
@@ -670,8 +679,8 @@ class Utility(object):
         if api_type in Utility.apitype_vs_structurename:
             field_detail[Constants.STRUCTURE_NAME] = Utility.apitype_vs_structurename.get(api_type)
 
-
-        if api_type.lower() == Constants.PICKLIST and field.get_pick_list_values() is not None and len(field.get_pick_list_values()) > 0:
+        if api_type.lower() == Constants.PICKLIST and field.get_pick_list_values() is not None and len(
+                field.get_pick_list_values()) > 0:
             field_detail[Constants.PICKLIST] = True
             values = list(map(lambda x: x.get_display_value(), field.get_pick_list_values()))
             field_detail[Constants.VALUES] = values
